/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Conrad Carlen (ccarlen@netscape.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

[uuid(2f977d57-5485-11d4-87e2-0010a4e75ef2)]
interface nsIProfileSharingSetup : nsISupports
{
  /**
   * enableSharing must be called by the application in order to use
   * profile sharing. It should be called as early as possible in the
   * startup sequence - before any use of profile data. If enabled,
   * sharing is enabled for all modules that support it.
   * 
   * @param aClientName   A non-versioned identifier of the current
   *                      application within the suite of applications
   *                      which share this profile. It is used to separate
   *                      the client's non-shared data from shared data
   *                      within the profile directory. Example: "browser"
   *                      or "mail" - not "ProductX 1.3b5"
   */
  void enableSharing(in AString aClientName);
  
  /**
   * sharingEnabled and clientName
   *
   * Attributes to be used by sharing-enabled components
   */
  readonly attribute boolean isSharingEnabled;
  readonly attribute AString clientName;
};
